# Savvy

Consolidated assortment of utility modules & classes for savvy Python development.

# Installation

```
$ pip install savvy
```

# Utilities

[Shell](./savvy/shell.py) - Class for secure sys calls with automatic error handling and log management.

More to come for sure.

# License

MIT